@@ -1,5 +1,5 @@
 package XML::Grammar::Fortune;
-
+$XML::Grammar::Fortune::VERSION = '0.0701';
 use warnings;
 use strict;
 
@@ -12,18 +12,70 @@ use MooX qw/late/;
 use XML::GrammarBase::Role::RelaxNG v0.2.2;
 use XML::GrammarBase::Role::XSLT v0.2.2;
 
-with ('XML::GrammarBase::Role::RelaxNG');
-with XSLT(output_format => 'html');
-
-has '+module_base' => (default => 'XML-Grammar-Fortune');
-has '+rng_schema_basename' => (default => 'fortune-xml.rng');
+with('XML::GrammarBase::Role::RelaxNG');
+with XSLT( output_format => 'html' );
 
+has '+module_base'         => ( default => 'XML-Grammar-Fortune' );
+has '+rng_schema_basename' => ( default => 'fortune-xml.rng' );
 
 has '+to_html_xslt_transform_basename' =>
-    (default => 'fortune-xml-to-html.xslt');
+    ( default => 'fortune-xml-to-html.xslt' );
 
-has '_mode' => (is => 'rw', init_arg => 'mode');
-has '_output_mode' => (is => 'rw', init_arg => 'output_mode',);
+has '_mode'        => ( is => 'rw', init_arg => 'mode' );
+has '_output_mode' => ( is => 'rw', init_arg => 'output_mode', );
+
+
+sub run
+{
+    my $self = shift;
+    my $args = shift;
+
+    my $xslt_params = $args->{'xslt_params'} || {};
+
+    my $output = $args->{'output'};
+    my $input  = $args->{'input'};
+
+    my $mode = $self->_mode();
+
+    if ( $mode eq "validate" )
+    {
+        return $self->rng_validate_file($input);
+    }
+    elsif ( $mode eq "convert_to_html" )
+    {
+        my $translate = sub {
+            my ( $medium, $encoding ) = @_;
+
+            return $self->perform_xslt_translation(
+                {
+                    output_format => 'html',
+                    source        => { file => $input },
+                    output        => $medium,
+                    encoding      => $encoding,
+                    xslt_params   => $xslt_params,
+                }
+            );
+        };
+        if ( $self->_output_mode() eq "string" )
+        {
+            $$output .= $translate->( 'string', 'bytes' );
+        }
+        else
+        {
+            $translate->( { file => $output }, 'utf8' );
+        }
+    }
+
+    return;
+}
+
+1;    # End of XML::Grammar::Fortune
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -31,12 +83,7 @@ XML::Grammar::Fortune - convert the FortunesXML grammar to other formats and fro
 
 =head1 VERSION
 
-Version 0.0600
-
-=cut
-
-our $VERSION = '0.0600';
-
+version 0.0701
 
 =head1 SYNOPSIS
 
@@ -71,6 +118,10 @@ our $VERSION = '0.0600';
         }
     );
 
+=head1 VERSION
+
+version 0.0701
+
 =head1 FUNCTIONS
 
 =head2 my $processor = XML::Grammar::Fortune->new({mode => $mode, input => $in, output => $out, output_mode => "string",});
@@ -99,56 +150,6 @@ Output destination - depends on output mode.
 
 =back
 
-=cut
-
-sub run
-{
-    my $self = shift;
-    my $args = shift;
-
-    my $xslt_params = $args->{'xslt_params'} || {};
-
-    my $output = $args->{'output'};
-    my $input = $args->{'input'};
-
-    my $mode = $self->_mode();
-
-    if ($mode eq "validate")
-    {
-        return $self->rng_validate_file($input);
-    }
-    elsif ($mode eq "convert_to_html")
-    {
-        my $translate = sub {
-            my ($medium, $encoding) = @_;
-
-            return $self->perform_xslt_translation(
-                {
-                    output_format => 'html',
-                    source => {file => $input},
-                    output => $medium,
-                    encoding => $encoding,
-                    xslt_params => $xslt_params,
-                }
-            );
-        };
-        if ($self->_output_mode() eq "string")
-        {
-            $$output .= $translate->('string', 'bytes');
-        }
-        else
-        {
-            $translate->({file => $output}, 'utf8');
-        }
-    }
-
-    return;
-}
-
-1; # End of XML::Grammar::Fortune
-
-__END__
-
 =head2 open
 
 This function is introduced by Fatal. It is mentioned here, in order to settle
@@ -170,7 +171,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc XML::Grammar::Fortune
 
-
 You can also look for information at:
 
 =over 4
@@ -193,7 +193,6 @@ L<http://search.cpan.org/dist/XML-Grammar-Fortune>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
@@ -224,5 +223,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=cut
+=head1 AUTHOR
 
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/xml-grammar-fortune/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc XML::Grammar::Fortune
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/XML-Grammar-Fortune>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/XML-Grammar-Fortune>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fortune>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-Grammar-Fortune>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-Grammar-Fortune>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fortune>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-Grammar-Fortune>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-Grammar-Fortune>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::Grammar::Fortune>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-xml-grammar-fortune at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-Grammar-Fortune>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/xml-grammar-fortune>
+
+  git clone git://github.com/shlomif/xml-grammar-fortune.git
+
+=cut
